==> mx-conky_19.12.tar.xz: mx-conky-19.12/translations/mx-conky_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="47"/>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>MX Conky</source>
        <translation>MX Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;This app enables detailed changes to the active conky. It supplements Conky Manager, which should be used for basic settings.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;Ta aplikacja umożliwia szczegółowe zmiany aktywnego Conky. Uzupełnia ona Menedżera Conky, który powinien być używany do podstawowych ustawień.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Launch</source>
        <translation>Uruchamianie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="85"/>
        <source>Run</source>
        <translation>Uruchom</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Conky Name</source>
        <translation>Nazwa Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="211"/>
        <source>Conky Manager</source>
        <translation>Menedżer Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Drag</source>
        <translation>Przeciągnij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>To Resize</source>
        <translation>Aby zmienić rozmiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>+ Left Click</source>
        <translation>+ Lewe Kliknięcie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>To Move</source>
        <translation>Aby przesunąć</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="288"/>
        <source>+ Right Click</source>
        <translation>+ Prawe Kliknięcie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="295"/>
        <source>NOTE: changes last only for the current session</source>
        <translation>UWAGA: zmiany obowiązują tylko dla bieżącej sesji</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Desktop</source>
        <translation>Pulpit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>Desktop 1</source>
        <translation>Pulpit 1</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <source>All Desktops</source>
        <translation>Wszystkie pulpity</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>Day</source>
        <translation>Dzień</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="517"/>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Long</source>
        <translation>Długi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Abbreviated name, e.g. Tu</source>
        <translation>Skrócona nazwa, np. Po</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <location filename="../mainwindow.ui" line="679"/>
        <source>Short</source>
        <translation>Krótki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="618"/>
        <source>Month</source>
        <translation>Miesiąc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>Abbreviated name, e.g. Oct</source>
        <translation>Skrócona nazwa, np. Sty</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <source>Colors</source>
        <translation>Kolory</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Default</source>
        <translation>Domyślny</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="830"/>
        <location filename="../mainwindow.ui" line="942"/>
        <location filename="../mainwindow.ui" line="1054"/>
        <location filename="../mainwindow.ui" line="1169"/>
        <location filename="../mainwindow.ui" line="1284"/>
        <location filename="../mainwindow.ui" line="1399"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="893"/>
        <source>Color0 </source>
        <translation>Kolor0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1005"/>
        <source>Color1 </source>
        <translation>Kolor1</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1117"/>
        <source>Color2 </source>
        <translation>Kolor2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1232"/>
        <source>Color3 </source>
        <translation>Kolor3</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1347"/>
        <source>Color4 </source>
        <translation>Kolor4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>About this application</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1465"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1481"/>
        <source>Display help </source>
        <translation>Wyświetl pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1484"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1491"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1539"/>
        <source>Quit application</source>
        <translation>Zakończ aplikację</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1542"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1549"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>About MX Conky</source>
        <translation>O programie MX Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="294"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>GUI program for configuring Conky in MX Linux</source>
        <translation>Narzędzie GUI do konfigurowania Conky w MX Linux.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="297"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Prawa autorskie © MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="298"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <location filename="../mainwindow.cpp" line="313"/>
        <source>Changelog</source>
        <translation>Dziennik zmian</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="321"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>MX Conky Help</source>
        <translation>Pomoc MX Conky</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="56"/>
        <location filename="../mainwindow.cpp" line="430"/>
        <source>Select Conky Manager config file</source>
        <translation>Wybierz plik konfiguracyjny Menedżera Conky</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Conky Data Update</source>
        <translation>Aktualizacja danych Conky</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>The MX Conky data set has been updated. &lt;p&gt;&lt;p&gt;                                  Copy from the folder where it is located &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;                                   whatever you wish to your Home hidden conky folder &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                   Be careful not to overwrite any conkies you have changed.</source>
        <translation>Zestaw danych MX Conky został zaktualizowany. &lt;p&gt;&lt;p&gt;                                  Skopiuj z folderu, w którym się znajduje &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;                                   cokolwiek chcesz do ukrytego folderu Conky w twoim katalogu domowym &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                   Uważaj, aby nie nadpisać żadnych Conky, które już zmieniłeś i skonfigurowałeś.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="100"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="101"/>
        <source>Could not find conky-manager, please install it before running mx-conky</source>
        <translation>Nie można znaleźć Menedżera Conky, zainstaluj go przed uruchomieniem MX Conky</translation>
    </message>
    <message>
        <source>No file was selected, quiting program</source>
        <translation type="vanished">Nie wybrano pliku, kończenie programu</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="134"/>
        <source>You must run this program as normal user</source>
        <translation>Musisz uruchomić ten program jako zwykły użytkownik</translation>
    </message>
</context>
</TS>

==> mx-conky_20.4.tar.xz: mx-conky-20.4/translations/mx-conky_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="54"/>
        <location filename="../mainwindow.cpp" line="542"/>
        <source>MX Conky</source>
        <translation>MX Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;This app enables detailed changes to the active conky. It supplements Conky Manager, which should be used for basic settings.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;Ta aplikacja umożliwia szczegółowe zmiany aktywnego Conky. Uzupełnia ona Menedżera Conky, który powinien być używany do podstawowych ustawień.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Launch</source>
        <translation>Uruchamianie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="85"/>
        <source>Run</source>
        <translation>Uruchom</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Conky Name</source>
        <translation>Nazwa Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="211"/>
        <source>Conky Manager</source>
        <translation>Menedżer Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>Drag</source>
        <translation>Przeciągnij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>To Resize</source>
        <translation>Aby zmienić rozmiar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>+ Left Click</source>
        <translation>+ Lewe Kliknięcie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>To Move</source>
        <translation>Aby przesunąć</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="288"/>
        <source>+ Right Click</source>
        <translation>+ Prawe Kliknięcie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="295"/>
        <source>NOTE: changes last only for the current session</source>
        <translation>UWAGA: zmiany obowiązują tylko dla bieżącej sesji</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Desktop</source>
        <translation>Pulpit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>Desktop 1</source>
        <translation>Pulpit 1</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <source>All Desktops</source>
        <translation>Wszystkie pulpity</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>Day</source>
        <translation>Dzień</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="517"/>
        <location filename="../mainwindow.ui" line="647"/>
        <source>Long</source>
        <translation>Długi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Abbreviated name, e.g. Tu</source>
        <translation>Skrócona nazwa, np. Po</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <location filename="../mainwindow.ui" line="679"/>
        <source>Short</source>
        <translation>Krótki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="618"/>
        <source>Month</source>
        <translation>Miesiąc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>Abbreviated name, e.g. Oct</source>
        <translation>Skrócona nazwa, np. Sty</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <source>Colors</source>
        <translation>Kolory</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Default</source>
        <translation>Domyślny</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="833"/>
        <location filename="../mainwindow.ui" line="948"/>
        <location filename="../mainwindow.ui" line="1063"/>
        <location filename="../mainwindow.ui" line="1181"/>
        <location filename="../mainwindow.ui" line="1299"/>
        <location filename="../mainwindow.ui" line="1417"/>
        <location filename="../mainwindow.ui" line="1532"/>
        <location filename="../mainwindow.ui" line="1647"/>
        <location filename="../mainwindow.ui" line="1762"/>
        <location filename="../mainwindow.ui" line="1877"/>
        <location filename="../mainwindow.ui" line="1992"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="896"/>
        <source>Color0 </source>
        <translation>Kolor0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1011"/>
        <source>Color1 </source>
        <translation>Kolor1</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1126"/>
        <source>Color2 </source>
        <translation>Kolor2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1244"/>
        <source>Color3 </source>
        <translation>Kolor3</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1362"/>
        <source>Color4 </source>
        <translation>Kolor4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1480"/>
        <source>Color5</source>
        <translation type="unfinished">Kolor4 {5?}</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1595"/>
        <source>Color6</source>
        <translation type="unfinished">Kolor4 {6?}</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1710"/>
        <source>Color7</source>
        <translation type="unfinished">Kolor4 {7?}</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1825"/>
        <source>Color8</source>
        <translation type="unfinished">Kolor4 {8?}</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1940"/>
        <source>Color9</source>
        <translation type="unfinished">Kolor4 {9?}</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2048"/>
        <source>About this application</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2051"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2058"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2074"/>
        <source>Display help </source>
        <translation>Wyświetl pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2077"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2084"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2132"/>
        <source>Quit application</source>
        <translation>Zakończ aplikację</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2135"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="2142"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="541"/>
        <source>About MX Conky</source>
        <translation>O programie MX Conky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="542"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="543"/>
        <source>GUI program for configuring Conky in MX Linux</source>
        <translation>Narzędzie GUI do konfigurowania Conky w MX Linux.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="545"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Prawa autorskie © MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="546"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="547"/>
        <location filename="../mainwindow.cpp" line="561"/>
        <source>Changelog</source>
        <translation>Dziennik zmian</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="569"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="588"/>
        <source>MX Conky Help</source>
        <translation>Pomoc MX Conky</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="56"/>
        <location filename="../mainwindow.cpp" line="712"/>
        <source>Select Conky Manager config file</source>
        <translation>Wybierz plik konfiguracyjny Menedżera Conky</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Conky Data Update</source>
        <translation>Aktualizacja danych Conky</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>The MX Conky data set has been updated. &lt;p&gt;&lt;p&gt;                                  Copy from the folder where it is located &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;                                   whatever you wish to your Home hidden conky folder &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                   Be careful not to overwrite any conkies you have changed.</source>
        <translation>Zestaw danych MX Conky został zaktualizowany. &lt;p&gt;&lt;p&gt;                                  Skopiuj z folderu, w którym się znajduje &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;                                   cokolwiek chcesz do ukrytego folderu Conky w twoim katalogu domowym &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                   Uważaj, aby nie nadpisać żadnych Conky, które już zmieniłeś i skonfigurowałeś.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="100"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="101"/>
        <source>Could not find conky-manager, please install it before running mx-conky</source>
        <translation>Nie można znaleźć Menedżera Conky, zainstaluj go przed uruchomieniem MX Conky</translation>
    </message>
    <message>
        <source>No file was selected, quiting program</source>
        <translation type="vanished">Nie wybrano pliku, kończenie programu</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="134"/>
        <source>You must run this program as normal user</source>
        <translation>Musisz uruchomić ten program jako zwykły użytkownik</translation>
    </message>
</context>
</TS>
